### R code from vignette source 'fanplot.Rnw'

###################################################
### code chunk number 1: fanplot.Rnw:20-21
###################################################
options(SweaveHooks=list(fig=function() par(mar=c(4,4,0.2,0))), continue=" ")


###################################################
### code chunk number 2: fanplot.Rnw:33-35
###################################################
library(fanplot)
head(svpdx)


###################################################
### code chunk number 3: fanplot.Rnw:38-46
###################################################
#plot
plot(svpdx$pdx, type = "l", xaxt = "n", xlab = "Time", ylab = "Return")
#x-axis
svpdx$rdate<-format(svpdx$date, format = "%b %Y")
mth <- unique(svpdx$rdate)
qtr <- mth[seq(1,length(mth),3)]
axis(1, at = match(qtr, svpdx$rdate), labels = qtr, cex.axis = 0.75)
axis(1, at = match(mth, svpdx$rdate), labels = FALSE, tcl = -0.2)


###################################################
### code chunk number 4: fanplot.Rnw:54-66
###################################################
library("R2OpenBUGS")
# write model file:
my1.bug <- dget(system.file("model", "my1.txt", package = "fanplot"))
write.model(my1.bug, "my1.txt")
# take a look:
file.show("my1.txt")
# run openbugs
my1.mcmc<-bugs(data=list(n=length(svpdx$pdx),y=svpdx$pdx),
               inits=list(list(phistar=0.975,mu=0,itau2=50)),
               param=c("mu","phi","tau","theta"),
               model="my1.txt",
               n.iter = 11000, n.burnin = 1000, n.chains = 1)


###################################################
### code chunk number 5: fanplot.Rnw:71-72
###################################################
th.mcmc <- my1.mcmc$sims.list$theta


###################################################
### code chunk number 6: fanplot.Rnw:75-76
###################################################
th.pn <- pn(sims = th.mcmc)


###################################################
### code chunk number 7: fanplot.Rnw:79-80
###################################################
head(th.pn[,c(1:3, 97:99)])


###################################################
### code chunk number 8: fanplot.Rnw:87-91
###################################################
#empty plot
plot(NULL, type = "n", xlim = c(1, 945), ylim = range(th.pn), ylab = "Theta")
#add fan
fan(th.pn) 


###################################################
### code chunk number 9: fanplot.Rnw:95-105
###################################################
#empty plot with x-axis added later
plot(NULL, type = "l", xlim = c(1, 945), xlab = "Time", xaxt = "n",
     ylim = range(th.pn), ylab = "Theta")
axis(1, at = match(qtr, svpdx$rdate), labels = qtr, cex.axis = 0.75)
axis(1, at = match(mth, svpdx$rdate), labels = FALSE, tcl = -0.2)
#add fan
fan(th.pn, txt = NA, ln = c(1,10,30,50,70,90,99))
#add text labels for percentiles
fan.txt(th.pn, pn.r = c(1,10,50,90,99))
fan.txt(th.pn, pn.l = c(1,30,70,99))


###################################################
### code chunk number 10: fanplot.Rnw:109-110
###################################################
pal <- colorRampPalette(c("royalblue", "grey", "white"))


###################################################
### code chunk number 11: fanplot.Rnw:113-114
###################################################
fancol <- pal(50)


###################################################
### code chunk number 12: fanplot.Rnw:117-118
###################################################
sigma.pn <- pn(sims = sqrt(exp(th.mcmc)))


###################################################
### code chunk number 13: fanplot.Rnw:121-128
###################################################
#empty plot with x-axis added later
plot(NULL, type = "l", xlim = c(1, 945), xlab = "Time", xaxt = "n",
     ylim = range(sigma.pn), ylab = "Standard Deviation")
axis(1, at = match(qtr, svpdx$rdate), labels = qtr, cex.axis = 0.75)
axis(1, at = match(mth, svpdx$rdate), labels = FALSE, tcl = -0.2)
#add fan
fan(sigma.pn, fan.col = fancol, ln = c(1, 10, 50, 90, 99))


###################################################
### code chunk number 14: fanplot.Rnw:135-137
###################################################
r <- diff(log(ew))
r <- ts(exp(r) - 1, 1841)


###################################################
### code chunk number 15: fanplot.Rnw:140-152
###################################################
library("R2OpenBUGS")
# write model file:
ew.bug<-dget(system.file("model/ew.txt", package = "fanplot"))
write.model(ew.bug, "ew.txt")
# take a look:
file.show("ew.txt")
# run openbugs
ew.mcmc <- bugs(data = list(N = length(r), H = 25, r = c(r), p = c(ew)),
                inits = list(list(a = exp(12), psi = 0.5, itau2 = 0.5)),
                param = c("alpha", "psi", "tau", "r.new", "p.new", "y.sim"),
                model = "ew.txt", 
                n.iter = 11000, n.burnin = 1000, n.chains = 1)


###################################################
### code chunk number 16: fanplot.Rnw:157-158
###################################################
y.mcmc <- ew.mcmc$sims.list$y.sim


###################################################
### code chunk number 17: fanplot.Rnw:161-162
###################################################
y.pn <- pn(sims = y.mcmc, start = 1842)


###################################################
### code chunk number 18: fanplot.Rnw:165-166
###################################################
str(y.pn)


###################################################
### code chunk number 19: fanplot.Rnw:169-176
###################################################
#empty plot
plot(NULL, type = "l", xlim = range(time(y.pn)), xlab = "Time",
     ylim = range(diff(r)), ylab = "Expected Model Fit")
#add fan
fan(y.pn, ln = c(1, 10, 90, 99))
#add data
lines(diff(r), lwd = 2)


###################################################
### code chunk number 20: fanplot.Rnw:180-181
###################################################
y.pn2 <- pn(sims = y.mcmc, p = c(1, 20, 40, 60, 80, 99), start = 1842)


###################################################
### code chunk number 21: fanplot.Rnw:186-193
###################################################
#empty plot
plot(NULL, type = "l", xlim = range(time(y.pn)), xlab = "Time",
     ylim = range(diff(r)), ylab = "Expected Model Fit")
#add fan
fan(y.pn2) 
#add data
lines(diff(r), lwd = 2)


###################################################
### code chunk number 22: fanplot.Rnw:198-200
###################################################
rnew.mcmc <- ew.mcmc$sims.list$r.new
pnew.mcmc <- ew.mcmc$sims.list$p.new


###################################################
### code chunk number 23: fanplot.Rnw:203-204
###################################################
rnew.pn <- pn(sims = rnew.mcmc, start = end(r)[1] + 1)


###################################################
### code chunk number 24: fanplot.Rnw:207-217
###################################################
par(mfrow = c(1 ,2))
#sample of underlying simulation data
plot(r, ylim = range(r), xlim = c(1940, 2040), 
     ylab = "Population Growth Rate", lwd = 2)
for (i in 1:30) lines(ts(rnew.mcmc[i, ], end(r)[1] + 1), col = "grey")
#plot r
plot(r, ylim = range(r), xlim = c(1940, 2040), 
     ylab = "Population Growth Rate", lwd = 2)
#add fan
fan(rnew.pn) 


###################################################
### code chunk number 25: fanplot.Rnw:221-225
###################################################
h0 <- end(ew)[1]
pnew.pn <- pn(sims = pnew.mcmc/1e+06, start = h0 + 1)
pnew.pn2 <- pn(sims = pnew.mcmc/1e+06, p = c(1, 10, 40, 50), 
    anchor = ew[length(ew)]/1e+06, start = h0)


###################################################
### code chunk number 26: fanplot.Rnw:230-241
###################################################
par(mfrow = c(1 ,2))
#plot pop
plot(ew/1e+06, ylim = c(40, 80), xlim = c(1940, 2040), 
     ylab = "Population (m)", lwd = 2)
#add fan
fan(pnew.pn)
#plot pop
plot(ew/1e+06, ylim = c(40, 80), xlim = c(1940, 2040), 
     ylab = "Population (m)", lwd = 2)
#add fan
fan(pnew.pn2, ln.col = "black") 


